@@ -6,7 +6,7 @@ use 5.008;
 use strict;
 use warnings;
 use Wx ':everything';
-use Wx::HTML ();
+use Wx::Html ();
 use Wx::Locale ();
 
 our $VERSION = '0.01';
